pub struct ModelRefSpec {
pub provider: String,
pub model: String,
}Expand description
Provider+model pair, parent-resolved. (Local mirror of ProviderModelRef;
this crate stays a leaf and does not depend on bamboo-domain.)
Fields
provider: Stringmodel: StringTrait Implementations
Sourceimpl Clone for ModelRefSpec
impl Clone for ModelRefSpec
Sourcefn clone(&self) -> ModelRefSpec
fn clone(&self) -> ModelRefSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelRefSpec
impl Debug for ModelRefSpec
Sourceimpl<'de> Deserialize<'de> for ModelRefSpec
impl<'de> Deserialize<'de> for ModelRefSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ModelRefSpec
impl PartialEq for ModelRefSpec
Sourcefn eq(&self, other: &ModelRefSpec) -> bool
fn eq(&self, other: &ModelRefSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModelRefSpec
impl Serialize for ModelRefSpec
impl StructuralPartialEq for ModelRefSpec