pub struct RootFields {
pub title: String,
pub updated_at: DateTime<Utc>,
}Expand description
Fields the index needs from a root session payload (for rebuild).
Fields
title: Stringupdated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for RootFields
impl Clone for RootFields
Sourcefn clone(&self) -> RootFields
fn clone(&self) -> RootFields
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RootFields
impl Debug for RootFields
Sourceimpl PartialEq for RootFields
impl PartialEq for RootFields
Sourcefn eq(&self, other: &RootFields) -> bool
fn eq(&self, other: &RootFields) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RootFields